==> haskell-distributive-0.6-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-distributive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: distributive
version: 0.6
id: distributive-0.6-1d7jorwc8Ju5fVx1MS8reC
key: distributive-0.6-1d7jorwc8Ju5fVx1MS8reC
license: BSD-3-Clause
copyright: Copyright (C) 2011-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/distributive/
synopsis: Distributive functors -- Dual to Traversable
description:
    Distributive functors -- Dual to @Traversable@
category: Data Structures
abi: 96f92a556e73debfe6b279551e3682d3
exposed: True
exposed-modules:
    Data.Distributive Data.Distributive.Generic
import-dirs: /usr/lib/ghc-8.6.1/site-local/distributive-0.6
library-dirs: /usr/lib/ghc-8.6.1/site-local/distributive-0.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/distributive-0.6
hs-libraries: HSdistributive-0.6-1d7jorwc8Ju5fVx1MS8reC
depends:
    base-4.12.0.0 base-orphans-0.8-11v3AdUy7xY4ICRrxxfp6Z
    tagged-0.8.6-FABECvKnqYbBCttH1EeJvB transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-distributive/html/distributive.haddock
haddock-html: /usr/share/doc/haskell-distributive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-distributive-0.6-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-distributive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: distributive
version: 0.6
id: distributive-0.6-DXoAeTRQfx24bGl75foabZ
key: distributive-0.6-DXoAeTRQfx24bGl75foabZ
license: BSD-3-Clause
copyright: Copyright (C) 2011-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/distributive/
synopsis: Distributive functors -- Dual to Traversable
description:
    Distributive functors -- Dual to @Traversable@
category: Data Structures
abi: 51672f5c57a960f8de5ce4e27e7c71de
exposed: True
exposed-modules:
    Data.Distributive Data.Distributive.Generic
import-dirs: /usr/lib/ghc-8.6.2/site-local/distributive-0.6
library-dirs: /usr/lib/ghc-8.6.2/site-local/distributive-0.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/distributive-0.6
hs-libraries: HSdistributive-0.6-DXoAeTRQfx24bGl75foabZ
depends:
    base-4.12.0.0 base-orphans-0.8-I5Wy5X7j4JPBlGRIrsmaA5
    tagged-0.8.6-FABECvKnqYbBCttH1EeJvB transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-distributive/html/distributive.haddock
haddock-html: /usr/share/doc/haskell-distributive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
